durationtools.TimespanConstant
==============================

.. inheritance-diagram:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant
   :private-bases:

.. autoclass:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.duration

.. autoattribute:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.start_offset

.. autoattribute:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.stop_offset

.. autoattribute:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.durationtools.TimespanConstant.TimespanConstant.TimespanConstant.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
